=================================
Flask-Neon-Kit
=================================
flask-neon-kit is a Flask extension which generates CRUD endpoints out of the box from defined models of the Neon Postgres database. This solution is built upon the foundation of the Flask-SQLAlchemy. This initiative was driven by the tedious nature of manually writing CRUD logic for every Flask application entity.

Features
===============
- Automatically generates CRUD endpoints from defined model.
- Allows to customize app base URL as well as each model's url prefix.
- Allows to paginate when getting many entities from database table.

Installation
===============
You can install flask-neon-kit via Python Package Index:

.. code:: bash

    pip install flask-neon-kit

Documentation
===============

`See Flask Neon Kit's Documentation. <https://github.com/ValentineSean/flask-neon-kit>`_